/* roadmap_track.h - Manage a route track: the list of street blocks.
 *
 * LICENSE:
 *
 *   Copyright 2002 Pascal F. Martin
 *
 *   This file is part of RoadMap.
 *
 *   RoadMap is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   RoadMap is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with RoadMap; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * DESCRIPTION:
 *
 *   This module handles the list of street blocks that makes a route. The
 *   route is computed elsewhere (possibly by another application), loaded
 *   one sequence of blocks at a time into this module.
 */

#ifndef INCLUDE__ROADMAP_TRACK__H
#define INCLUDE__ROADMAP_TRACK__H

void  roadmap_track_clear (void);

void  roadmap_track_add_lines (int fips, int lines[], int count);

/* The functions above are used to load a specific track. The caller
 * should start by calling roadmap_track_clear() to delete the existing
 * track, then loop loading lines.
 * All loaded tracks are considered as "ahead" of the vehicule.
 */


void roadmap_track_behind (int fips, int line);

/* This function declares the specified line as "behind" the vehicule.
 * This should be called when the vehicule exited the street block.
 * This way the track will be marked "behind" as the vehicule follows
 * the route.
 */


typedef void (* RoadMapTrackAction) (int line);

void  roadmap_track_visible_lines (RoadMapTrackAction action, int filter);

#define ROADMAP_TRACK_AHEAD
#define ROADMAP_TRACK_BEHIND
#define ROADMAP_TRACK_ANY

/* Searching through the visible lines of the track is done using
 * an iterator. The visibility is defined in roadmap_math.c.
 * The iterator's callback function should assume the proper
 * map has been activated.
 * The filter argument make it possible to process only track matching
 * the given state. When ROADMAP_TRACK_ANY is used, no filtering takes
 * place.
 */

#endif // INCLUDE__ROADMAP_TRACK__H
